==> financial-settlement-domain-0.1.143-sources.jar: com/xforceplus/ultraman/app/financialsettlement/entity/ReturnMoneyRecordView.java <==
package com.xforceplus.ultraman.app.financialsettlement.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2022-07-25
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ReturnMoneyRecordView implements Serializable {

  private static final long serialVersionUID=1L;

  /**
   * 认领时间
   */
  @TableField("takenTime")
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime takenTime;

  /**
   * 操作人
   */
  private String operator;

  /**
   * 认领金额
   */
  @TableField("takenAmount")
  private BigDecimal takenAmount;

  /**
   * 交易流水号
   */
  @TableField("tradeNo")
  private String tradeNo;

  /**
   * 订单号
   */
  @TableField("orderNo")
  private String orderNo;

  /**
   * 产品名称
   */
  @TableField("productName")
  private String productName;

  /**
   * 产品code
   */
  @TableField("productCode")
  private String productCode;

  /**
   * 合同编号
   */
  @TableField("contractNo")
  private String contractNo;

  /**
   * 合同原始id
   */
  @TableField("contractId")
  private String contractId;

  /**
   * 项目名称
   */
  @TableField("projectNo")
  private String projectNo;

  /**
   * 服务收费类型
   */
  @TableField("serviceType")
  private String serviceType;

  /**
   * 产品税率
   */
  private BigDecimal rate;

  /**
   * 是否外包
   */
  private String outsourcing;

  /**
   * 经营单元
   */
  @TableField("businessUnit")
  private String businessUnit;

  /**
   * id
   */
  private Long id;

  /**
   * 租户ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人ID
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   * 流程类型(2)
   */
  @TableField("processType")
  private String processType;

  /**
   * 项目Code
   */
  @TableField("projectCode")
  private String projectCode;

  /**
   * 大区
   */
  private String region;

  /**
   * 维度说明(3)
   */
  @TableField("dimensionEnum")
  private String dimensionEnum;

  /**
   * 功能模块(1)
   */
  @TableField("moduleEnum")
  private String moduleEnum;

  /**
   * 说明
   */
  private String result;

  /**
   * 项目分期名称
   */
  @TableField("projectItemName")
  private String projectItemName;

  /**
   * 项目分期Code
   */
  @TableField("projectItemCode")
  private String projectItemCode;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("takenTime", BocpGenUtils.toTimestamp(takenTime));
      map.put("operator", operator);
      map.put("takenAmount", takenAmount);
      map.put("tradeNo", tradeNo);
      map.put("orderNo", orderNo);
      map.put("productName", productName);
      map.put("productCode", productCode);
      map.put("contractNo", contractNo);
      map.put("contractId", contractId);
      map.put("projectNo", projectNo);
      map.put("serviceType", serviceType);
      map.put("rate", rate);
      map.put("outsourcing", outsourcing);
      map.put("businessUnit", businessUnit);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("processType", processType);
      map.put("projectCode", projectCode);
      map.put("region", region);
      map.put("dimensionEnum", dimensionEnum);
      map.put("moduleEnum", moduleEnum);
      map.put("result", result);
      map.put("projectItemName", projectItemName);
      map.put("projectItemCode", projectItemCode);
      return map;
  }

  public static ReturnMoneyRecordView fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    ReturnMoneyRecordView entity = new ReturnMoneyRecordView();
    if(map.containsKey("takenTime")) {
      Object obj = map.get("takenTime");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTakenTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setTakenTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setTakenTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setTakenTime(null);
      }
    }
    if(map.containsKey("operator")) {
      Object obj = map.get("operator");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOperator((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("takenAmount")) {
      Object obj = map.get("takenAmount");
      if(obj != null) {
        if(obj instanceof BigDecimal) {
          entity.setTakenAmount((BigDecimal)obj);
        } else if(obj instanceof Long) {
          entity.setTakenAmount(BigDecimal.valueOf((Long)obj));
        } else if(obj instanceof Double) {
          entity.setTakenAmount(BigDecimal.valueOf((Double)obj));
        } else if(obj instanceof String) {
          entity.setTakenAmount(new BigDecimal((String)obj));
        } else if(obj instanceof Integer) {
          entity.setTakenAmount(BigDecimal.valueOf(Long.parseLong(obj.toString())));
        }
      } else{
      }
    }
    if(map.containsKey("tradeNo")) {
      Object obj = map.get("tradeNo");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTradeNo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("orderNo")) {
      Object obj = map.get("orderNo");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOrderNo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("productName")) {
      Object obj = map.get("productName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProductName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("productCode")) {
      Object obj = map.get("productCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProductCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("contractNo")) {
      Object obj = map.get("contractNo");
      if(obj != null) {
        if(obj instanceof String){
          entity.setContractNo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("contractId")) {
      Object obj = map.get("contractId");
      if(obj != null) {
        if(obj instanceof String){
          entity.setContractId((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("projectNo")) {
      Object obj = map.get("projectNo");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProjectNo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("serviceType")) {
      Object obj = map.get("serviceType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setServiceType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("rate")) {
      Object obj = map.get("rate");
      if(obj != null) {
        if(obj instanceof BigDecimal) {
          entity.setRate((BigDecimal)obj);
        } else if(obj instanceof Long) {
          entity.setRate(BigDecimal.valueOf((Long)obj));
        } else if(obj instanceof Double) {
          entity.setRate(BigDecimal.valueOf((Double)obj));
        } else if(obj instanceof String) {
          entity.setRate(new BigDecimal((String)obj));
        } else if(obj instanceof Integer) {
          entity.setRate(BigDecimal.valueOf(Long.parseLong(obj.toString())));
        }
      } else{
      }
    }
    if(map.containsKey("outsourcing")) {
      Object obj = map.get("outsourcing");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOutsourcing((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("businessUnit")) {
      Object obj = map.get("businessUnit");
      if(obj != null) {
        if(obj instanceof String){
          entity.setBusinessUnit((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("processType")) {
      Object obj = map.get("processType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProcessType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("projectCode")) {
      Object obj = map.get("projectCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProjectCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("region")) {
      Object obj = map.get("region");
      if(obj != null) {
        if(obj instanceof String){
          entity.setRegion((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("dimensionEnum")) {
      Object obj = map.get("dimensionEnum");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDimensionEnum((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("moduleEnum")) {
      Object obj = map.get("moduleEnum");
      if(obj != null) {
        if(obj instanceof String){
          entity.setModuleEnum((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("result")) {
      Object obj = map.get("result");
      if(obj != null) {
        if(obj instanceof String){
          entity.setResult((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("projectItemName")) {
      Object obj = map.get("projectItemName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProjectItemName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("projectItemCode")) {
      Object obj = map.get("projectItemCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProjectItemCode((String)obj);
        }
      } else{
      }
    }
    return entity;
  }
}

==> financial-settlement-domain-0.1.217-sources.jar: com/xforceplus/ultraman/app/financialsettlement/entity/ReturnMoneyRecordView.java <==
package com.xforceplus.ultraman.app.financialsettlement.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2022-08-22
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ReturnMoneyRecordView implements Serializable {

  private static final long serialVersionUID=1L;

  /**
   * 认领时间
   */
  @TableField("takenTime")
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime takenTime;

  /**
   * 操作人
   */
  private String operator;

  /**
   * 认领金额
   */
  @TableField("takenAmount")
  private BigDecimal takenAmount;

  /**
   * 交易流水号
   */
  @TableField("tradeNo")
  private String tradeNo;

  /**
   * 订单号
   */
  @TableField("orderNo")
  private String orderNo;

  /**
   * 产品名称
   */
  @TableField("productName")
  private String productName;

  /**
   * 产品code
   */
  @TableField("productCode")
  private String productCode;

  /**
   * 合同编号
   */
  @TableField("contractNo")
  private String contractNo;

  /**
   * 合同原始id
   */
  @TableField("contractId")
  private String contractId;

  /**
   * 项目名称
   */
  @TableField("projectNo")
  private String projectNo;

  /**
   * 服务收费类型
   */
  @TableField("serviceType")
  private String serviceType;

  /**
   * 产品税率
   */
  private BigDecimal rate;

  /**
   * 是否外包
   */
  private String outsourcing;

  /**
   * 经营单元
   */
  @TableField("businessUnit")
  private String businessUnit;

  /**
   * id
   */
  private Long id;

  /**
   * 租户ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人ID
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   * 流程类型(2)
   */
  @TableField("processType")
  private String processType;

  /**
   * 项目Code
   */
  @TableField("projectCode")
  private String projectCode;

  /**
   * 大区
   */
  private String region;

  /**
   * 维度说明(3)
   */
  @TableField("dimensionEnum")
  private String dimensionEnum;

  /**
   * 功能模块(1)
   */
  @TableField("moduleEnum")
  private String moduleEnum;

  /**
   * 说明
   */
  private String result;

  /**
   * 项目分期名称
   */
  @TableField("projectItemName")
  private String projectItemName;

  /**
   * 项目分期Code
   */
  @TableField("projectItemCode")
  private String projectItemCode;

  /**
   * 回执编号
   */
  @TableField("voucherNo")
  private String voucherNo;

  /**
   * 回款流水数据来源
   */
  private String channel;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("takenTime", BocpGenUtils.toTimestamp(takenTime));
      map.put("operator", operator);
      map.put("takenAmount", takenAmount);
      map.put("tradeNo", tradeNo);
      map.put("orderNo", orderNo);
      map.put("productName", productName);
      map.put("productCode", productCode);
      map.put("contractNo", contractNo);
      map.put("contractId", contractId);
      map.put("projectNo", projectNo);
      map.put("serviceType", serviceType);
      map.put("rate", rate);
      map.put("outsourcing", outsourcing);
      map.put("businessUnit", businessUnit);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("processType", processType);
      map.put("projectCode", projectCode);
      map.put("region", region);
      map.put("dimensionEnum", dimensionEnum);
      map.put("moduleEnum", moduleEnum);
      map.put("result", result);
      map.put("projectItemName", projectItemName);
      map.put("projectItemCode", projectItemCode);
      map.put("voucherNo", voucherNo);
      map.put("channel", channel);
      return map;
  }

  public static ReturnMoneyRecordView fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    ReturnMoneyRecordView entity = new ReturnMoneyRecordView();
    if(map.containsKey("takenTime")) {
      Object obj = map.get("takenTime");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTakenTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setTakenTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setTakenTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setTakenTime(null);
      }
    }
    if(map.containsKey("operator")) {
      Object obj = map.get("operator");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOperator((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("takenAmount")) {
      Object obj = map.get("takenAmount");
      if(obj != null) {
        if(obj instanceof BigDecimal) {
          entity.setTakenAmount((BigDecimal)obj);
        } else if(obj instanceof Long) {
          entity.setTakenAmount(BigDecimal.valueOf((Long)obj));
        } else if(obj instanceof Double) {
          entity.setTakenAmount(BigDecimal.valueOf((Double)obj));
        } else if(obj instanceof String) {
          entity.setTakenAmount(new BigDecimal((String)obj));
        } else if(obj instanceof Integer) {
          entity.setTakenAmount(BigDecimal.valueOf(Long.parseLong(obj.toString())));
        }
      } else{
      }
    }
    if(map.containsKey("tradeNo")) {
      Object obj = map.get("tradeNo");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTradeNo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("orderNo")) {
      Object obj = map.get("orderNo");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOrderNo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("productName")) {
      Object obj = map.get("productName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProductName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("productCode")) {
      Object obj = map.get("productCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProductCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("contractNo")) {
      Object obj = map.get("contractNo");
      if(obj != null) {
        if(obj instanceof String){
          entity.setContractNo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("contractId")) {
      Object obj = map.get("contractId");
      if(obj != null) {
        if(obj instanceof String){
          entity.setContractId((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("projectNo")) {
      Object obj = map.get("projectNo");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProjectNo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("serviceType")) {
      Object obj = map.get("serviceType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setServiceType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("rate")) {
      Object obj = map.get("rate");
      if(obj != null) {
        if(obj instanceof BigDecimal) {
          entity.setRate((BigDecimal)obj);
        } else if(obj instanceof Long) {
          entity.setRate(BigDecimal.valueOf((Long)obj));
        } else if(obj instanceof Double) {
          entity.setRate(BigDecimal.valueOf((Double)obj));
        } else if(obj instanceof String) {
          entity.setRate(new BigDecimal((String)obj));
        } else if(obj instanceof Integer) {
          entity.setRate(BigDecimal.valueOf(Long.parseLong(obj.toString())));
        }
      } else{
      }
    }
    if(map.containsKey("outsourcing")) {
      Object obj = map.get("outsourcing");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOutsourcing((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("businessUnit")) {
      Object obj = map.get("businessUnit");
      if(obj != null) {
        if(obj instanceof String){
          entity.setBusinessUnit((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("processType")) {
      Object obj = map.get("processType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProcessType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("projectCode")) {
      Object obj = map.get("projectCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProjectCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("region")) {
      Object obj = map.get("region");
      if(obj != null) {
        if(obj instanceof String){
          entity.setRegion((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("dimensionEnum")) {
      Object obj = map.get("dimensionEnum");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDimensionEnum((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("moduleEnum")) {
      Object obj = map.get("moduleEnum");
      if(obj != null) {
        if(obj instanceof String){
          entity.setModuleEnum((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("result")) {
      Object obj = map.get("result");
      if(obj != null) {
        if(obj instanceof String){
          entity.setResult((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("projectItemName")) {
      Object obj = map.get("projectItemName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProjectItemName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("projectItemCode")) {
      Object obj = map.get("projectItemCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setProjectItemCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("voucherNo")) {
      Object obj = map.get("voucherNo");
      if(obj != null) {
        if(obj instanceof String){
          entity.setVoucherNo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("channel")) {
      Object obj = map.get("channel");
      if(obj != null) {
        if(obj instanceof String){
          entity.setChannel((String)obj);
        }
      } else{
      }
    }
    return entity;
  }
}
